@@ -595,6 +595,11 @@ class Observer(SchedulerBase):
                               args=twilight)
         return(np.float64(twi))
 
+    def night_length(self, mjd=None, twilight=None):
+        morning = self.morning_twilight(mjd=mjd, twilight=twilight)
+        evening = self.evening_twilight(mjd=mjd, twilight=twilight)
+        return morning - evening
+
     def _moon_rise_set(self, mjd=None):
         """Utility function for root-finding to get moon rise/set times"""
         (alt, az) = self.moon_altaz(mjd=mjd)
@@ -930,9 +935,10 @@ class Scheduler(Master):
         self.nExpPriAward = priorities.get("nExpPriAward", 1e5)
         self.nExpPriPenalty = priorities.get("nExpPriPenalty", -5)
         self.basePri = priorities.get("basePri", 100)
-        self.lstPri = priorities.get("lstPri", 200)
+        self.lstPri = priorities.get("lstPri", 400)
         self.overheadPri = priorities.get("overheadPri", 40)
         self.remainAward = priorities.get("remainAward", 100)
+        self.airmassPri = priorities.get("airmassPri", 20)
 
         return
 
@@ -977,7 +983,7 @@ class Scheduler(Master):
         surveyGoal = np.sum(self.fields.slots)
         surveyDone = np.sum([len(self.fields.hist[i]) for i in self.fields.pk])
 
-        self.surveyComplete = (surveyGoal - surveyDone) / surveyGoal
+        self.surveyComplete = surveyDone / surveyGoal
 
         self.observations = roboscheduler.observations.Observations(observatory=self.observatory)
         return
@@ -1090,9 +1096,12 @@ class Scheduler(Master):
                 continue
 
             if epoch_idx > 0:
-                exp_epoch = expCount[epoch_idx-1] - len(mjd_past)
+                exp_epoch = len(mjd_past) - expCount[epoch_idx - 1]
+                last_idx = expCount[epoch_idx - 1] - 1
+                mjd_prev = mjd_past[last_idx]
             else:
                 exp_epoch = len(mjd_past)
+                mjd_prev = 0
 
             nexp[indx] = cadence.nexp[epoch_idx] - exp_epoch
             partial_epoch = exp_epoch > 0
@@ -1100,15 +1109,11 @@ class Scheduler(Master):
             exp_epochs[indx] = exp_epoch
             epoch_idxs[indx] = epoch_idx
 
-            if len(mjd_past):
-                mjd_prev = mjd_past[-1]
-            else:
-                mjd_prev = 0
-
             if nexp[indx] > nexp_change and self.fields.flag[indx] != 1:
                 # change between bright/dark, field doesn't fit
                 observable[indx] = False
                 continue
+
             observable[indx], delta_priority[indx] =\
                 cadence.evaluate_next(epoch_idx=epoch_idx,
                                       partial_epoch=partial_epoch,
@@ -1117,14 +1122,15 @@ class Scheduler(Master):
                                       skybrightness_next=skybrightness,
                                       moon_dist=moon_dist[indx],
                                       deltaV=deltav[indx],
-                                      airmass=airmass[indx])
+                                      airmass=airmass[indx],
+                                      verbose=False)
 
-            percent_remain = (expCount[-1] - len(mjd_past))/expCount[-1]
+            percent_done = len(mjd_past) / expCount[-1]
 
-            if percent_remain > self.surveyComplete:
+            if percent_done < self.surveyComplete:
                 delta_priority[indx] += self.remainAward
 
-            delta_priority[indx] += nExpPrioritize(nexp[indx],
+            delta_priority[indx] += nExpPrioritize(cadence.nexp[epoch_idx],
                                                    base=self.nExpPriBase,
                                                    award=self.nExpPriAward,
                                                    penalty=self.nExpPriPenalty)
@@ -1180,13 +1186,6 @@ class Scheduler(Master):
         # priority = self.fields.basePriority[fieldid]
         priority += delta_priority
 
-        # # #################
-        # # #################
-        # # GRRRRRR
-        # # #################
-        # # #################
-        # priority += np.power(2, nexp) * 5  # 1280 for RM
-
         lst = self.lst(mjd)
 
         lstHrs = lst/15
@@ -1202,6 +1201,11 @@ class Scheduler(Master):
         ha = self.ralst2ha(ra=ra, lst=lst)
         dec = self.fields.deccen[iobservable]
 
+        (alt, az) = self.radec2altaz(mjd=mjd, ra=ra, dec=dec)
+        airmass = self.alt2airmass(alt) - 1
+
+        priority += self.airmassPri * np.exp(-(airmass)**2 / (2 * 0.2**2))
+
         # gaussian weight, mean already 0, use 1 hr  std
         priority += self.lstPri * np.exp(-(lstDiffs)**2 / (2 * 0.5**2))
         # gaussian weight, mean already 0, use 1 hr = 15 deg std
@@ -1288,7 +1292,7 @@ class Scheduler(Master):
 
         designs = list(len(mjd_past) + np.arange(exp_to_do))
 
-        print(self.fields.field_id[fieldidx], len(mjd_past), designs)
+        # print(self.fields.field_id[fieldidx], len(mjd_past), designs)
 
         return designs
 
@@ -1333,13 +1337,7 @@ class Scheduler(Master):
 
         iobservable, nexp, delta_priority, exp_epoch, epoch_idx\
             = self.observable(mjd=mjd, maxExp=maxExp, ignore=ignore)
-        # if(len(iobservable) == 0) and live:
-        #     # in a sim we'll take the dead time, should write something to track this better
-        #     # print("Nothing observable")
-        #     iobservable, nexp, delta_priority, exp_epoch, epoch_idx\
-        #         = self.observable(mjd=mjd, maxExp=maxExp, ignore=ignore)
         if len(iobservable) == 0:
-            # print("!! nothing to observe; {} exp left in the night".format(maxExp))
             if returnAll:
                 return None, -1
             return None, -1
@@ -1350,11 +1348,6 @@ class Scheduler(Master):
         if returnAll:
             # inverse priority, highest first
             sorted_priority = np.argsort(priority)[::-1]
-            # for i in sorted_priority:
-            #     field_idx = iobservable[i]
-            #     print(i, priority[i], nexp[i],
-            #           self.fields.pk[field_idx],
-            #           self.fields.cadence[field_idx])
             sorted_idx = [iobservable[i] for i in sorted_priority]
             sorted_fields = [self.fields.pk[i] for i in sorted_idx]
             sorted_exp = [nexp[i] for i in sorted_priority]
@@ -1365,21 +1358,11 @@ class Scheduler(Master):
 
             return sorted_fields, sorted_exp
 
-        # considered = False
-        # print(observable_fieldid)
-        # print(priority, self.fields.cadence[observable_fieldid])
-        # for p, c, i in zip(priority, np.array(self.fields.cadence)[observable_fieldid], observable_fieldid):
-        #     if "RM" in c.upper():
-        #         print(c, i, p, np.max(priority))
-        #         considered = True
+        observable_fieldpk = self.fields.pk[iobservable]
+        # field_ids = self.fields.field_id[iobservable]
 
-        observable_fieldid = self.fields.pk[iobservable]
-
-        # field_pk, next_exp = self.pick(priority=priority,
-        #                                fieldid=observable_fieldid,
-        #                                nexp=nexp)
         ipick = np.argmax(priority)
-        field_pk = observable_fieldid[ipick]
+        field_pk = observable_fieldpk[ipick]
         next_exp = nexp[ipick]
         pick_exp_epoch = exp_epoch[ipick]
         pick_epoch_idx = epoch_idx[ipick]
